@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use Gtk2::Ex::Simple::List;
-use Gscan2pdf::Frontend::Scanimage;
+use Gscan2pdf::Scanner::Options;
 use Gscan2pdf::Frontend::Sane;
 use Gscan2pdf::Page;
 use Glib qw(TRUE FALSE);
@@ -1510,8 +1510,8 @@ sub open_session {
   my $tar = Archive::Tar->new( $filename, TRUE );
   @filenamelist = $tar->list_files;
   $tar->extract;
+  $dir = dirname( $filenamelist[0] );
  }
- $dir = dirname( $filenamelist[0] );
  my $sessionref = retrieve( File::Spec->catfile( $dir, 'session' ) );
  my %session = %$sessionref;
 
